import { PressResponder } from "@react-aria/interactions";
import { useOverlayTriggerState } from "@react-stately/overlays";
import { Modal, Popover, Tray } from "@ladifire-ui-react/overlays";
import { Heading } from "@ladifire-ui-react/text";
import { Divider } from "@ladifire-ui-react/divider";
import _ladifireCssSassComponentsDialogScss from "@ladifire-css/sass/components/dialog.scss";
import _ladifireCssSassIndexScss from "@ladifire-css/sass/index.scss";
import { useDialog } from "@react-aria/dialog";
import { Grid } from "@ladifire-ui-react/layout";
import { FocusScope } from "@react-aria/focus";
import { DismissButton, useOverlayPosition, useOverlayTrigger } from "@react-aria/overlays";
import * as _react from "react";
import { ICloseIcon } from "@ladifire-ui-react/icons";
import _babelRuntimeHelpersEsmExtends from "@babel/runtime/helpers/esm/extends";
import { Content } from "@ladifire-ui-react/view";
import { classNames, useStyleProps, SlotProvider, unwrapDOMRef, useDOMRef, useHasChild, useMediaQuery } from "@react-spectrum/utils";
import { chain, mergeProps } from "@react-aria/utils";
import { ButtonGroup } from "@ladifire-ui-react/buttongroup";
import { Button } from "@ladifire-ui-react/button";
import _spectrumIconsUiAlertMedium from "@spectrum-icons/ui/AlertMedium";
import _babelRuntimeHelpersEsmObjectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import "./main.css";

function $parcel$interopDefault(a) {
  return a && a.__esModule ? a.default : a;
}

const $ffc9f78f30ca8b06355670729977e2e4$export$DialogContext = /*#__PURE__*/_react.createContext(null);

let $b9143cd9d6c80f3c0ae6540a70f3f$var$sizeMap = {
  S: 'small',
  M: 'medium',
  L: 'large',
  fullscreen: 'fullscreen',
  fullscreenTakeover: 'fullscreenTakeover'
};

function $b9143cd9d6c80f3c0ae6540a70f3f$var$Dialog(props, ref) {
  let _ref = _react.useContext($ffc9f78f30ca8b06355670729977e2e4$export$DialogContext) || {},
      {
    type = 'modal'
  } = _ref,
      contextProps = _babelRuntimeHelpersEsmObjectWithoutPropertiesLoose(_ref, ["type"]);

  let {
    children,
    isDismissable = contextProps.isDismissable,
    onDismiss = contextProps.onClose,
    size,
    scrolled,
    headingClassName,
    headerClassName,
    heroClassName,
    typeIconClassName,
    dividerClassName,
    contentClassName,
    footerClassName,
    buttonGroupClassName
  } = props,
      otherProps = _babelRuntimeHelpersEsmObjectWithoutPropertiesLoose(props, ["children", "isDismissable", "onDismiss", "size", "scrolled", "headingClassName", "headerClassName", "heroClassName", "typeIconClassName", "dividerClassName", "contentClassName", "footerClassName", "buttonGroupClassName"]);

  let {
    styleProps
  } = useStyleProps(otherProps);
  size = type === 'popover' ? size || 'S' : size || 'L';
  let domRef = useDOMRef(ref);

  let gridRef = _react.useRef();

  let sizeVariant = $b9143cd9d6c80f3c0ae6540a70f3f$var$sizeMap[type] || $b9143cd9d6c80f3c0ae6540a70f3f$var$sizeMap[size];
  let {
    dialogProps,
    titleProps
  } = useDialog(mergeProps(contextProps, props), domRef);
  let hasHeader = useHasChild("." + _ladifireCssSassComponentsDialogScss.dialog__heading, unwrapDOMRef(gridRef));
  let hasFooter = useHasChild("." + _ladifireCssSassComponentsDialogScss.dialog__footer, unwrapDOMRef(gridRef));
  let slots = {
    hero: {
      UNSAFE_className: classNames(_ladifireCssSassComponentsDialogScss, _ladifireCssSassComponentsDialogScss.dialog__hero, heroClassName)
    },
    header: {
      UNSAFE_className: classNames(_ladifireCssSassComponentsDialogScss, _ladifireCssSassComponentsDialogScss.dialog__header, classNames(_ladifireCssSassIndexScss, _ladifireCssSassIndexScss.display__flex, _ladifireCssSassIndexScss.align_item__center), headerClassName)
    },
    heading: _babelRuntimeHelpersEsmExtends({
      UNSAFE_className: classNames(_ladifireCssSassComponentsDialogScss, _ladifireCssSassComponentsDialogScss.dialog__heading, {
        [_ladifireCssSassComponentsDialogScss.dialog__heading_no__header]: !hasHeader
      }, classNames(_ladifireCssSassIndexScss, _ladifireCssSassIndexScss.display__flex, _ladifireCssSassIndexScss.align_item__center), headingClassName)
    }, titleProps),
    typeIcon: {
      UNSAFE_className: classNames(_ladifireCssSassIndexScss, _ladifireCssSassComponentsDialogScss.dialog__type_icon, typeIconClassName)
    },
    divider: {
      UNSAFE_className: classNames(_ladifireCssSassComponentsDialogScss, _ladifireCssSassComponentsDialogScss.dialog__divider, dividerClassName),
      shadow: scrolled,
      size: 'M'
    },
    content: {
      UNSAFE_className: classNames(_ladifireCssSassComponentsDialogScss, _ladifireCssSassComponentsDialogScss.dialog__content, contentClassName)
    },
    footerDivider: {
      UNSAFE_className: classNames(_ladifireCssSassComponentsDialogScss, _ladifireCssSassComponentsDialogScss.dialog__footer_divider, classNames(_ladifireCssSassIndexScss, _ladifireCssSassIndexScss.height__1, _ladifireCssSassIndexScss.margin_top__0))
    },
    footer: {
      UNSAFE_className: classNames(_ladifireCssSassComponentsDialogScss, _ladifireCssSassComponentsDialogScss.dialog__footer, footerClassName)
    },
    buttonGroup: {
      UNSAFE_className: classNames(_ladifireCssSassComponentsDialogScss, _ladifireCssSassComponentsDialogScss.dialog__buttonGroup, {
        [_ladifireCssSassComponentsDialogScss.dialog__buttonGroup_no_footer]: !hasFooter
      }, buttonGroupClassName),
      align: 'end'
    }
  }; // If rendered in a popover or tray there won't be a visible dismiss button,
  // so we render a hidden one for screen readers.

  let dismissButton;

  if (type === 'popover' || type === 'tray') {
    dismissButton = /*#__PURE__*/_react.createElement(DismissButton, {
      onDismiss: onDismiss
    });
  }

  return /*#__PURE__*/_react.createElement(FocusScope, {
    contain: true,
    restoreFocus: true
  }, /*#__PURE__*/_react.createElement("section", _babelRuntimeHelpersEsmExtends({}, styleProps, dialogProps, {
    ref: domRef,
    className: classNames(_ladifireCssSassIndexScss, _ladifireCssSassIndexScss.display__flex, _ladifireCssSassIndexScss.box_sizing__border_box, _ladifireCssSassIndexScss.width__fit_content, _ladifireCssSassIndexScss.max_width__100_percent, _ladifireCssSassIndexScss.max_height__inherit, _ladifireCssSassIndexScss.outline__none, _ladifireCssSassIndexScss.width__100_percent, classNames(_ladifireCssSassComponentsDialogScss, _ladifireCssSassComponentsDialogScss.dialog__min_width), // classNames(
    //   styles,
    //   'spectrum-Dialog',
    //   {
    //     [`spectrum-Dialog--${sizeVariant}`]: sizeVariant,
    //     'spectrum-Dialog--dismissable': isDismissable
    //   },
    //   styleProps.className
    // ),
    styleProps.className) // className={classNames(
    //   styles,
    //   'spectrum-Dialog',
    //   {
    //     [`spectrum-Dialog--${sizeVariant}`]: sizeVariant,
    //     'spectrum-Dialog--dismissable': isDismissable
    //   },
    //   styleProps.className
    // )}

  }), /*#__PURE__*/_react.createElement(Grid, {
    ref: gridRef,
    UNSAFE_className: classNames(_ladifireCssSassIndexScss, _ladifireCssSassIndexScss.width__100_percent, classNames(_ladifireCssSassComponentsDialogScss, {
      [_ladifireCssSassComponentsDialogScss.dialog__grid]: !isDismissable,
      [_ladifireCssSassComponentsDialogScss.dialog__dismissable]: isDismissable
    }))
  }, /*#__PURE__*/_react.createElement(SlotProvider, {
    slots: slots
  }, children), isDismissable && /*#__PURE__*/_react.createElement(Button, {
    variant: "secondary",
    square: true,
    rounded: true,
    className: classNames(_ladifireCssSassComponentsDialogScss, _ladifireCssSassComponentsDialogScss.dialog__closeButton, classNames(_ladifireCssSassIndexScss, _ladifireCssSassIndexScss.margin_right__12, _ladifireCssSassIndexScss.margin_top__8)),
    "aria-label": "dismiss",
    onPress: onDismiss
  }, /*#__PURE__*/_react.createElement(ICloseIcon, {
    filter: "secondary-icon"
  }))), dismissButton));
}
/**
 * Dialogs are windows containing contextual information, tasks, or workflows that appear over the user interface.
 * Depending on the kind of Dialog, further interactions may be blocked until the Dialog is acknowledged.
 */


export let Dialog = /*#__PURE__*/_react.forwardRef($b9143cd9d6c80f3c0ae6540a70f3f$var$Dialog);
// ASSET: /mnt/01D4AF1F1FC8FE60/Github/chot.sale/ladifire-ui-react/node_modules/@adobe/spectrum-css-temp/components/dialog/vars.css
var $eb3a317262722c9956cb0987c60c4bd$exports = {};
$eb3a317262722c9956cb0987c60c4bd$exports = {
  "spectrum-Dialog": "_spectrum-Dialog_7388d",
  "spectrum-Dialog--small": "_spectrum-Dialog--small_7388d",
  "spectrum-Dialog--medium": "_spectrum-Dialog--medium_7388d",
  "spectrum-Dialog--large": "_spectrum-Dialog--large_7388d",
  "spectrum-Dialog-hero": "_spectrum-Dialog-hero_7388d",
  "spectrum-Dialog-grid": "_spectrum-Dialog-grid_7388d",
  "spectrum-Dialog-heading": "_spectrum-Dialog-heading_7388d",
  "spectrum-Dialog-heading--noHeader": "_spectrum-Dialog-heading--noHeader_7388d",
  "spectrum-Dialog-header": "_spectrum-Dialog-header_7388d",
  "spectrum-Dialog-typeIcon": "_spectrum-Dialog-typeIcon_7388d",
  "spectrum-Dialog-divider": "_spectrum-Dialog-divider_7388d",
  "spectrum-Dialog--noDivider": "_spectrum-Dialog--noDivider_7388d",
  "spectrum-Dialog-content": "_spectrum-Dialog-content_7388d",
  "spectrum-Dialog-footer": "_spectrum-Dialog-footer_7388d",
  "spectrum-Button": "_spectrum-Button_7388d",
  "spectrum-Dialog-buttonGroup": "_spectrum-Dialog-buttonGroup_7388d",
  "spectrum-Dialog-buttonGroup--noFooter": "_spectrum-Dialog-buttonGroup--noFooter_7388d",
  "spectrum-Dialog--dismissable": "_spectrum-Dialog--dismissable_7388d",
  "spectrum-Dialog-closeButton": "_spectrum-Dialog-closeButton_7388d",
  "spectrum-Dialog--error": "_spectrum-Dialog--error_7388d",
  "spectrum-Dialog--fullscreen": "_spectrum-Dialog--fullscreen_7388d",
  "spectrum-Dialog--fullscreenTakeover": "_spectrum-Dialog--fullscreenTakeover_7388d",
  "spectrum-Dialog--warning": "_spectrum-Dialog--warning_7388d"
};
var $eb3a317262722c9956cb0987c60c4bd$$interop$default = $parcel$interopDefault($eb3a317262722c9956cb0987c60c4bd$exports);

/**
 * AlertDialogs are a specific type of Dialog. They display important information that users need to acknowledge.
 */
function $aa97cf95f2b1c005c9c9d0821de17d3e$var$AlertDialog(props, ref) {
  let {
    onClose = () => {}
  } = _react.useContext($ffc9f78f30ca8b06355670729977e2e4$export$DialogContext) || {};

  let {
    variant,
    children,
    primaryActionLabel,
    secondaryActionLabel,
    cancelLabel,
    autoFocusButton,
    title,
    isPrimaryActionDisabled,
    isSecondaryActionDisabled,
    onCancel = () => {},
    onPrimaryAction = () => {},
    onSecondaryAction = () => {}
  } = props,
      otherProps = _babelRuntimeHelpersEsmObjectWithoutPropertiesLoose(props, ["variant", "children", "primaryActionLabel", "secondaryActionLabel", "cancelLabel", "autoFocusButton", "title", "isPrimaryActionDisabled", "isSecondaryActionDisabled", "onCancel", "onPrimaryAction", "onSecondaryAction"]);

  let {
    styleProps
  } = useStyleProps(otherProps);
  let confirmVariant = 'primary';

  if (variant) {
    if (variant === 'confirmation') {
      confirmVariant = 'cta';
    } else if (variant === 'destructive') {
      confirmVariant = 'negative';
    }
  }

  return /*#__PURE__*/_react.createElement(Dialog, {
    UNSAFE_style: styleProps.style,
    UNSAFE_className: classNames($eb3a317262722c9956cb0987c60c4bd$$interop$default, {
      ["spectrum-Dialog--" + variant]: variant
    }, styleProps.className),
    isHidden: styleProps.hidden,
    size: "M",
    role: "alertdialog",
    ref: ref
  }, /*#__PURE__*/_react.createElement(Heading, null, title), (variant === 'error' || variant === 'warning') && /*#__PURE__*/_react.createElement(_spectrumIconsUiAlertMedium, {
    slot: "typeIcon",
    "aria-label": "alert"
  }), /*#__PURE__*/_react.createElement(Divider, null), /*#__PURE__*/_react.createElement(Content, null, children), /*#__PURE__*/_react.createElement(ButtonGroup, {
    align: "end"
  }, cancelLabel && /*#__PURE__*/_react.createElement(Button, {
    variant: "secondary",
    onPress: () => chain(onClose(), onCancel()),
    autoFocus: autoFocusButton === 'cancel'
  }, cancelLabel), secondaryActionLabel && /*#__PURE__*/_react.createElement(Button, {
    variant: "secondary",
    onPress: () => chain(onClose(), onSecondaryAction()),
    isDisabled: isSecondaryActionDisabled,
    autoFocus: autoFocusButton === 'secondary'
  }, secondaryActionLabel), /*#__PURE__*/_react.createElement(Button, {
    variant: confirmVariant,
    onPress: () => chain(onClose(), onPrimaryAction()),
    isDisabled: isPrimaryActionDisabled,
    autoFocus: autoFocusButton === 'primary'
  }, primaryActionLabel)));
}
/**
 * AlertDialogs are a specific type of Dialog. They display important information that users need to acknowledge.
 */


export let AlertDialog = /*#__PURE__*/_react.forwardRef($aa97cf95f2b1c005c9c9d0821de17d3e$var$AlertDialog);

function $f82d6b5c401a89d78f532f3f249f5b$var$DialogTrigger(props) {
  let {
    children,
    type = 'modal',
    mobileType = type === 'popover' ? 'modal' : type,
    hideArrow,
    targetRef,
    isDismissable,
    scrollContent,
    closeConfirm,
    confirmProps
  } = props,
      positionProps = _babelRuntimeHelpersEsmObjectWithoutPropertiesLoose(props, ["children", "type", "mobileType", "hideArrow", "targetRef", "isDismissable", "scrollContent", "closeConfirm", "confirmProps"]);

  if (!Array.isArray(children) || children.length > 2) {
    throw new Error('DialogTrigger must have exactly 2 children');
  } // if a function is passed as the second child, it won't appear in toArray


  let [trigger, content] = children; // On small devices, show a modal or tray instead of a popover.
  // TODO: DNA variable?

  let isMobile = useMediaQuery('(max-width: 700px)');

  if (isMobile) {
    // handle cases where desktop popovers need a close button for the mobile modal view
    if (type !== 'modal' && mobileType === 'modal') {
      isDismissable = true;
    }

    type = mobileType;
  }

  let state = useOverlayTriggerState(props);

  if (type === 'popover') {
    return /*#__PURE__*/_react.createElement($f82d6b5c401a89d78f532f3f249f5b$var$PopoverTrigger, _babelRuntimeHelpersEsmExtends({}, positionProps, {
      state: state,
      targetRef: targetRef,
      trigger: trigger,
      content: content,
      hideArrow: hideArrow
    }));
  }

  const [showConfirm, setShowConfirm] = _react.useState(false);

  const handleDismiss = () => {
    setShowConfirm(true);
  };

  const handleShowConfirmChange = show => {
    setShowConfirm(show);
  };

  const handleClose = () => {
    setShowConfirm(false);
    state.close();
  };

  let renderOverlay = () => {
    switch (type) {
      case 'fullscreen':
      case 'fullscreenTakeover':
        return /*#__PURE__*/_react.createElement(Modal, {
          isOpen: state.isOpen,
          isDismissable: false,
          onClose: handleClose,
          type: type,
          scrollContent: scrollContent,
          closeConfirm: closeConfirm,
          confirmProps: confirmProps,
          showConfirm: showConfirm,
          onShowConfirmChange: handleShowConfirmChange
        }, typeof content === 'function' ? content(closeConfirm ? handleDismiss : handleClose) : content);

      case 'modal':
        return /*#__PURE__*/_react.createElement("div", null, /*#__PURE__*/_react.createElement(Modal, {
          isOpen: state.isOpen,
          isDismissable: isDismissable,
          onClose: handleClose,
          scrollContent: scrollContent,
          closeConfirm: closeConfirm,
          confirmProps: confirmProps,
          showConfirm: showConfirm,
          onShowConfirmChange: handleShowConfirmChange
        }, typeof content === 'function' ? content(closeConfirm ? handleDismiss : handleClose) : content));

      case 'tray':
        return /*#__PURE__*/_react.createElement(Tray, {
          isOpen: state.isOpen,
          onClose: handleClose
        }, typeof content === 'function' ? content(closeConfirm ? handleDismiss : handleClose) : content);
    }
  };

  return /*#__PURE__*/_react.createElement($f82d6b5c401a89d78f532f3f249f5b$var$DialogTriggerBase, {
    type: type,
    state: state,
    isDismissable: isDismissable,
    closeConfirm: closeConfirm,
    onDismiss: handleDismiss,
    trigger: trigger,
    overlay: renderOverlay()
  });
} // Support DialogTrigger inside components using CollectionBuilder.


$f82d6b5c401a89d78f532f3f249f5b$var$DialogTrigger.getCollectionNode = function* (props) {
  let [trigger] = _react.Children.toArray(props.children);

  let [, content] = props.children;
  yield {
    element: trigger,
    wrapper: element => /*#__PURE__*/_react.createElement($f82d6b5c401a89d78f532f3f249f5b$var$DialogTrigger, _babelRuntimeHelpersEsmExtends({
      key: element.key
    }, props), element, content)
  };
};
/**
 * DialogTrigger serves as a wrapper around a Dialog and its associated trigger, linking the Dialog's
 * open state with the trigger's press state. Additionally, it allows you to customize the type and
 * positioning of the Dialog.
 */
// We don't want getCollectionNode to show up in the type definition


export let DialogTrigger = $f82d6b5c401a89d78f532f3f249f5b$var$DialogTrigger;

function $f82d6b5c401a89d78f532f3f249f5b$var$PopoverTrigger(_ref) {
  let {
    state,
    targetRef,
    trigger,
    content,
    hideArrow
  } = _ref,
      props = _babelRuntimeHelpersEsmObjectWithoutPropertiesLoose(_ref, ["state", "targetRef", "trigger", "content", "hideArrow"]);

  let triggerRef = _react.useRef();

  let overlayRef = _react.useRef();

  let {
    overlayProps: popoverProps,
    placement,
    arrowProps
  } = useOverlayPosition({
    targetRef: targetRef || triggerRef,
    overlayRef: unwrapDOMRef(overlayRef),
    placement: props.placement,
    containerPadding: props.containerPadding,
    offset: props.offset,
    crossOffset: props.crossOffset,
    shouldFlip: props.shouldFlip,
    isOpen: state.isOpen
  });
  let {
    triggerProps,
    overlayProps
  } = useOverlayTrigger({
    type: 'dialog'
  }, state, triggerRef);

  let triggerPropsWithRef = _babelRuntimeHelpersEsmExtends({}, triggerProps, {
    ref: targetRef ? undefined : triggerRef
  });

  let overlay = /*#__PURE__*/_react.createElement(Popover, {
    isOpen: state.isOpen,
    UNSAFE_style: popoverProps.style,
    ref: overlayRef,
    onClose: state.close,
    placement: placement,
    arrowProps: arrowProps,
    hideArrow: hideArrow
  }, content);

  return /*#__PURE__*/_react.createElement($f82d6b5c401a89d78f532f3f249f5b$var$DialogTriggerBase, {
    type: "popover",
    state: state,
    triggerProps: triggerPropsWithRef,
    dialogProps: overlayProps,
    trigger: trigger,
    overlay: overlay
  });
}

function $f82d6b5c401a89d78f532f3f249f5b$var$DialogTriggerBase(_ref2) {
  let {
    type,
    state,
    isDismissable,
    onDismiss,
    closeConfirm,
    dialogProps = {},
    triggerProps = {},
    overlay,
    trigger
  } = _ref2;

  let context = _babelRuntimeHelpersEsmExtends({
    type,
    closeConfirm,
    onClose: closeConfirm ? onDismiss : state.close,
    isDismissable
  }, dialogProps);

  return /*#__PURE__*/_react.createElement(_react.Fragment, null, /*#__PURE__*/_react.createElement(PressResponder, _babelRuntimeHelpersEsmExtends({}, triggerProps, {
    onPress: state.toggle,
    isPressed: state.isOpen && type !== 'modal' && type !== 'fullscreen' && type !== 'fullscreenTakeover'
  }), trigger), /*#__PURE__*/_react.createElement($ffc9f78f30ca8b06355670729977e2e4$export$DialogContext.Provider, {
    value: context
  }, overlay));
}
//# sourceMappingURL=module.js.map
